@@ -45,12 +45,10 @@ package inc::MBX::Alien::FLTK;
             unshift @ISA, $platform;
         }
         my $self = $class->SUPER::new(@_);
-        $self->notes(platform       => \@platform);
-        $self->notes(os             => $OS);
-        $self->notes(cc             => $CC);
-        $self->notes(errors         => []);
-        $self->notes('include_dirs' => {});
-        $self->notes('lib_dirs'     => {});
+        $self->notes(platform => \@platform);
+        $self->notes(os       => $OS);
+        $self->notes(cc       => $CC);
+        $self->notes(errors   => []);
         return $self;
     }
 
@@ -91,6 +89,6 @@ Creative Commons Attribution-Share Alike 3.0 License. See
 http://creativecommons.org/licenses/by-sa/3.0/us/legalcode.  For
 clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 
-=for git $Id: FLTK.pm dfa6aa4 2010-01-16 21:12:51Z sanko@cpan.org $
+=for git $Id: FLTK.pm dc42150 2010-01-17 03:51:57Z sanko@cpan.org $
 
 =cut
